@@ -47,7 +47,7 @@ class API:
         """Perform request."""
         async with self._session.request(
             method,
-            self._url.join(URL(uri)) % params,
+            self._url.join(URL(uri)).update_query(params),
             json=data,
             headers={"Accept": "application/json", "X-API-Key": self._api_key,},
             timeout=self._timeout,
@@ -57,6 +57,6 @@ class API:
             return await response.json()
 
     async def close(self):
-        """Perform request without error wrapping."""
+        """Close the session."""
         if self._session and self._close_session:
             await self._session.close()
